/**
 * Distribution License:
 * JSword is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License, version 2.1 as published by
 * the Free Software Foundation. This program is distributed in the hope
 * that it will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * The License is available on the internet at:
 *       http://www.gnu.org/copyleft/lgpl.html
 * or by writing to:
 *      Free Software Foundation, Inc.
 *      59 Temple Place - Suite 330
 *      Boston, MA 02111-1307, USA
 *
 * Copyright: 2005
 *     The copyright to this program is held by it's authors.
 *
 * ID: $Id: Field.java,v 1.5 2005/07/27 23:26:43 dmsmith Exp $
 */
package org.crosswire.common.config.swing;

import javax.swing.JComponent;

import org.crosswire.common.config.Choice;

/**
 * A Field is an interface for a visual representation of a Choice.
 * 
 * @see gnu.lgpl.License for license details.
 *      The copyright to this program is held by it's authors.
 * @author Joe Walker [joe at eireneh dot com]
 */
public interface Field
{
    /**
     * Some fields will need some extra info to display properly
     * like the options in an options field. FieldMap calls this
     * method with options provided by the choice.
     * @param param The options provided by the Choice
     */
    void setChoice(Choice param);

    /**
     * Return a string version of the current value
     * @return The current value
     */
    String getValue();

    /**
     * Set the current value.
     * @param value The new text
     */
    void setValue(String value);

    /**
     * Get the actual component that we can add to a Panel.
     * (This can well be <code>this</code> in an implementation).
     */
    JComponent getComponent();
}
